@@ -22,7 +22,6 @@ CONFIG_SCHEMA = Schema({
     # Optional('id'): Use(basestring, error='invalid identity'),
     Optional('id'): basestring,
     Optional('live'): bool,
-    Optional('frequency'): basestring,
     Optional('_id'): object,
     Optional('__v'): object,
     'modules': {
@@ -35,8 +34,11 @@ CONFIG_SCHEMA = Schema({
 })
 
 
-PANDAS_FREQ = {
-    'daily': 'D',
-    'hourly': 'H',
-    'minutely': 'Min'
+FINANCE_URLS = {
+    'yahoo_hist': 'http://ichart.yahoo.com/table.csv',
+    'yahoo_infos': 'http://finance.yahoo/q/pr',
+    'google_prices': 'http://www.google.com/finance/getprices',
+    'snapshot_google_light': 'http://www.google.com/finance/info',
+    'info_lookup': ('http://d.yimg.com/autoc.finance.yahoo.com/autoc?' +
+                    'query={}&callback=YAHOO.Finance.SymbolSuggest.ssCallback')
 }
